// Include standard libraries.
#include <iostream>
#include <string>

// Include own libraries.
#include "TinyPort.h"

class Main {
	public:
		Main();
		~Main();
		void run(std::string server);
};

/**
 * This is the standard constructor.
 * It does pretty nothing.
 */
Main::Main() {
	std::cout << "Starting simulation ..." << std::endl;
}

/**
 * This is the standard destructor.
 * It does pretty nothing.
 */
Main::~Main() {
	std::cout << "Simulation finished ..." << std::endl;
}

/**
 * The run function holds the test program,
 * which is used to test the ray tracer.
 */
void Main::run(std::string host) {
	try {
		TinyPort scanner;
		scanner.scan(host);
  }
  
  catch (std::exception& e) {
		std::cerr << e.what() << std::endl;
	} 
}

int main(int argc, char* argv[]) {
	// Check if enough arguments were given.
	if (argc < 2) {
		// Dump error messages.
		std::cerr << "Usage: ./tinyport <host>" << std::endl;
		std::cerr << "Example: ./tinyport 127.0.0.1" << std::endl;

		return 1;
	}
	
	// Instance the test class ...
	Main simulation;
	
	// ... and start the simulation.
	simulation.run(argv[1]);

	return 0;
}
