#ifndef TINY_TCP_IP_CPP
#define TINY_TCP_IP_CPP

// Include the needed headers.
#include <sstream>

// Include header file.
#include "TinyTcpIp.h"

TinyTcpIp::TinyTcpIp() {
	this->resolver = new tcp::resolver(io_service);
}

TinyTcpIp::~TinyTcpIp() {
}

void TinyTcpIp::connect(
		std::string host,
		int port) {
		
	// Store the host name and port, ...
	this->host = host;
	std::stringstream temp;
	temp << port;
	this->port = temp.str();
	
	// Generate list of endpoints ...
	tcp::resolver::query query(
		host.c_str(), 
		this->port
	);
	
	// ... and iterators to loop over the endpoints
	tcp::resolver::iterator endpoint_iterator = this->resolver->resolve(query);
	tcp::resolver::iterator end;
	
	// Initialize the socket.
	socket = new tcp::socket(io_service);
	boost::system::error_code error = boost::asio::error::host_not_found;

	// Try to connect to the server.
	while (error && endpoint_iterator != end) {
		this->socket->close();
		this->socket->connect(*endpoint_iterator++, error);
	}
	
	// Boost system error detected.
	if (error) {
		throw boost::system::system_error(error);
	}
}

std::string TinyTcpIp::read() {
	// Initialize result stream.
	std::stringstream result;

	// Loop while there is something to read.
	for (;;) {
		// Init needed variables ...
		boost::array<char, 4096> buf;
		boost::system::error_code error;

		// ... and read data from stream.
		this->socket->read_some(boost::asio::buffer(buf), error);

		// Check if end of stream was reached ...
		if (error == boost::asio::error::eof) {
			// ... and exit loop if so.
			break;
		}
		
		// Check for other errors ...
		else if (error) {
			// ... and throw an exception if one occured.
			throw boost::system::system_error(error);
		}
		
		// Finally append result.
		result << buf.data();
	}
	
	return result.str();
}

void TinyTcpIp::write(std::string request) {
	// Add data to log stream.
	this->logData.append(request);
	
	// Prepare the request data.
	boost::asio::streambuf requestString;
	std::ostream request_stream(&requestString);
	request_stream << request;

	// Send the request.
	boost::asio::write(*this->socket, requestString);
}

#endif
